<template>
    <Head title="Major"/>
    <AdminMainLayout>
        <div class="card">
            <div class="card-body">
                <div class="card-title">
                    <div class="d-flex justify-content-between align-items-center">
                        <h4>Jurusan</h4>
                        <BaseButton class="btn-primary" @click="openCreateModal">
                            Tambah Jurusan
                        </BaseButton>
                    </div>
                </div>
                <div class="table-responsive">
                    <div class="d-flex align-items-center gap-2 mb-3">
                        <BaseInput v-model="search" placeholder="Cari Jurusan"/>
                        <i class="fas fa-times text-secondary cursor-pointer" @click="search = ''" v-if="search"/>
                    </div>
                    <table class="table">
                        <thead>
                        <tr>
                            <th>No</th>
                            <th>Nama Jurusan</th>
                            <th>Action</th>
                        </tr>
                        </thead>
                        <tbody>
                        <tr v-for="(major, index) in data.data" :key="major.id" v-if="data.data.length > 0">
                            <td>{{ index + 1 }}</td>
                            <td>{{ major.name }}</td>
                            <td>
                                <div class="d-flex gap-2">
                                <span
                                    @click="openEditModal(major)"
                                    class="cursor-pointer">
                                    <i class="fas fa-pen text-secondary"></i>
                                </span>
                                    <span
                                        @click="idDelete = major.id"
                                        class="cursor-pointer">
                                    <i class="fas fa-trash text-danger"></i>
                                </span>
                                </div>
                            </td>
                        </tr>
                        <tr v-else>
                            <td colspan="3" class="text-center">No data available</td>
                        </tr>
                        </tbody>
                    </table>
                    <PaginationLink :links="data.links" class="mt-3"/>
                </div>
            </div>
        </div>

        <!-- Confirmation Modal -->
        <BaseConfirmation
            title="Yakin Menghapus?"
            message="Data yang dihapus tidak dapat dikembalikan"
            :is-visible="idDelete !== null"
            @confirmed="deleteMajor"
            @close="idDelete = null"
        />

        <!-- Modal Create / Edit -->
        <BaseModal
            :title="mode === 1 ? 'Buat Jurusan' : 'Ubah Jurusan'"
            :is-visible="isShowModal"
            size="modal-md"
            @close="isShowModal = false"
        >
            <template #body>
                <form @submit.prevent="submit">
                    <BaseInput
                        v-model="form.name"
                        :error-message="form.errors.name"
                        label="Nama Jurusan"/>
                </form>
            </template>
            <template #footer>
                <BaseButton class="btn-primary" @click="submit">
                    {{ mode === 1 ? 'Create' : 'Update' }}
                </BaseButton>
            </template>
        </BaseModal>
    </AdminMainLayout>
</template>

<script setup>
import {Head, router, useForm} from '@inertiajs/vue3';
import PaginationLink from "@/Components/Table/PaginationLink.vue";
import BaseButton from "@/Components/Button/BaseButton.vue";
import {ref, watch} from "vue";
import BaseModal from "@/Components/Modal/BaseModal.vue";
import BaseInput from "@/Components/Forms/BaseInput.vue";
import BaseConfirmation from "@/Components/Modal/BaseConfirmation.vue";
import AdminMainLayout from "@/Layouts/AdminMainLayout.vue";
import debounce from "lodash/debounce";

defineProps({
    data: {
        type: Object
    }
})

const isShowModal = ref(false);
const mode = ref(1); // 1 = create, 2 = update
const form = useForm({
    id: null,
    name: '',
});
const idDelete = ref(null);
const search = ref(window.location.search ? new URLSearchParams(window.location.search).get('search') : '');
const openCreateModal = () => {
    mode.value = 1;
    form.id = null;
    form.name = '';
    isShowModal.value = true;
};

const openEditModal = (major) => {
    mode.value = 2;
    form.id = major.id;
    form.name = major.name;
    isShowModal.value = true;
};

const submit = () => {
    if (mode.value === 1) {
        form.post('/backoffice/admin/major', {
            onSuccess: () => {
                isShowModal.value = false;
            }
        });
    } else {
        form.put(`/backoffice/admin/major/${form.id}`, {
            onSuccess: () => {
                isShowModal.value = false;
            }
        });
    }
};

const deleteMajor = () => {
    router.delete(`/backoffice/admin/major/${idDelete.value}`, {
        onSuccess: () => {
            idDelete.value = null;
        }
    });
};

watch(search, debounce((value) => {
    router.get(window.location.pathname, {
        search: value
    });
}, 800));
</script>
